@@ -29,7 +29,9 @@
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
+#ifndef UPOWER_CI_DISABLE_PLATFORM_CODE
 #include <dev/acpica/acpiio.h>
+#endif
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -47,14 +49,13 @@
 
 G_DEFINE_TYPE (UpDeviceSupply, up_device_supply, UP_TYPE_DEVICE)
 
-static gboolean		 up_device_supply_refresh	 	(UpDevice *device);
+static gboolean		 up_device_supply_refresh	 	(UpDevice *device, UpRefreshReason reason);
 static UpDeviceTechnology	up_device_supply_convert_device_technology (const gchar *type);
 static gboolean		up_device_supply_acline_coldplug	(UpDevice *device);
 static gboolean		up_device_supply_battery_coldplug	(UpDevice *device, UpAcpiNative *native);
 static gboolean		up_device_supply_acline_set_properties	(UpDevice *device);
 static gboolean		up_device_supply_battery_set_properties	(UpDevice *device, UpAcpiNative *native);
 static gboolean		up_device_supply_get_on_battery	(UpDevice *device, gboolean *on_battery);
-static gboolean		up_device_supply_get_low_battery	(UpDevice *device, gboolean *low_battery);
 static gboolean		up_device_supply_get_online		(UpDevice *device, gboolean *online);
 
 /**
@@ -156,6 +157,7 @@ up_device_supply_battery_coldplug (UpDevice *device, UpAcpiNative *native)
 static gboolean
 up_device_supply_battery_set_properties (UpDevice *device, UpAcpiNative *native)
 {
+#ifndef UPOWER_CI_DISABLE_PLATFORM_CODE
 	gint fd;
 	gdouble volt, dvolt, rate, lastfull, cap, dcap, lcap, capacity;
 	gboolean is_present;
@@ -318,6 +320,9 @@ up_device_supply_battery_set_properties (UpDevice *device, UpAcpiNative *native)
 end:
 	close (fd);
 	return ret;
+#else
+	return FALSE;
+#endif
 }
 
 /**
@@ -326,12 +331,14 @@ end:
 static gboolean
 up_device_supply_acline_set_properties (UpDevice *device)
 {
+#ifndef UPOWER_CI_DISABLE_PLATFORM_CODE
 	int acstate;
 
 	if (up_get_int_sysctl (&acstate, NULL, "hw.acpi.acline")) {
 		g_object_set (device, "online", acstate ? TRUE : FALSE, NULL);
 		return TRUE;
 	}
+#endif
 
 	return FALSE;
 }
@@ -380,10 +387,9 @@ out:
  * Return %TRUE on success, %FALSE if we failed to refresh or no data
  **/
 static gboolean
-up_device_supply_refresh (UpDevice *device)
+up_device_supply_refresh (UpDevice *device, UpRefreshReason reason)
 {
 	GObject *object;
-	GTimeVal timeval;
 	UpDeviceKind type;
 	gboolean ret;
 
@@ -401,10 +407,8 @@ up_device_supply_refresh (UpDevice *device)
 			break;
 	}
 
-	if (ret) {
-		g_get_current_time (&timeval);
-		g_object_set (device, "update-time", (guint64) timeval.tv_sec, NULL);
-	}
+	if (ret)
+		g_object_set (device, "update-time", (guint64) g_get_real_time () / G_USEC_PER_SEC, NULL);
 
 	return ret;
 }
@@ -438,32 +442,6 @@ up_device_supply_get_on_battery (UpDevice *device, gboolean *on_battery)
 	return TRUE;
 }
 
-/**
- * up_device_supply_get_low_battery:
- **/
-static gboolean
-up_device_supply_get_low_battery (UpDevice *device, gboolean *low_battery)
-{
-	gboolean ret;
-	gboolean on_battery;
-	gdouble percentage;
-
-	g_return_val_if_fail (low_battery != NULL, FALSE);
-
-	ret = up_device_supply_get_on_battery (device, &on_battery);
-	if (!ret)
-		return FALSE;
-
-	if (!on_battery) {
-		*low_battery = FALSE;
-		return TRUE;
-	}
-
-	g_object_get (device, "percentage", &percentage, NULL);
-	*low_battery = (percentage < 10.0f);
-	return TRUE;
-}
-
 /**
  * up_device_supply_get_online:
  **/
@@ -496,45 +474,16 @@ up_device_supply_init (UpDeviceSupply *supply)
 {
 }
 
-/**
- * up_device_supply_finalize:
- **/
-static void
-up_device_supply_finalize (GObject *object)
-{
-	UpDeviceSupply *supply;
-
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (UP_IS_DEVICE_SUPPLY (object));
-
-	supply = UP_DEVICE_SUPPLY (object);
-
-	G_OBJECT_CLASS (up_device_supply_parent_class)->finalize (object);
-}
-
 /**
  * up_device_supply_class_init:
  **/
 static void
 up_device_supply_class_init (UpDeviceSupplyClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	UpDeviceClass *device_class = UP_DEVICE_CLASS (klass);
 
-	object_class->finalize = up_device_supply_finalize;
 	device_class->get_on_battery = up_device_supply_get_on_battery;
-	device_class->get_low_battery = up_device_supply_get_low_battery;
 	device_class->get_online = up_device_supply_get_online;
 	device_class->coldplug = up_device_supply_coldplug;
 	device_class->refresh = up_device_supply_refresh;
 }
-
-/**
- * up_device_supply_new:
- **/
-UpDeviceSupply *
-up_device_supply_new (void)
-{
-	return g_object_new (UP_TYPE_DEVICE_SUPPLY, NULL);
-}
-
