@@ -83,14 +83,13 @@
 
 struct UpDeviceHidPrivate
 {
-	guint			 poll_timer_id;
 	int			 fd;
 	gboolean		 fake_device;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (UpDeviceHid, up_device_hid, UP_TYPE_DEVICE)
 
-static gboolean		 up_device_hid_refresh	 	(UpDevice *device);
+static gboolean		 up_device_hid_refresh	 	(UpDevice *device, UpRefreshReason reason);
 
 /**
  * up_device_hid_is_ups:
@@ -122,21 +121,6 @@ out:
 	return ret;
 }
 
-/**
- * up_device_hid_poll:
- **/
-static gboolean
-up_device_hid_poll (UpDeviceHid *hid)
-{
-	UpDevice *device = UP_DEVICE (hid);
-
-	g_debug ("Polling: %s", up_device_get_object_path (device));
-	up_device_hid_refresh (device);
-
-	/* always continue polling */
-	return TRUE;
-}
-
 /**
  * up_device_hid_get_string:
  **/
@@ -376,6 +360,8 @@ up_device_hid_coldplug (UpDevice *device)
 
 	/* fix up device states */
 	up_device_hid_fixup_state (device);
+
+	g_object_set (device, "poll-timeout", UP_DEVICE_HID_REFRESH_TIMEOUT, NULL);
 out:
 	return ret;
 }
@@ -386,7 +372,7 @@ out:
  * Return %TRUE on success, %FALSE if we failed to refresh or no data
  **/
 static gboolean
-up_device_hid_refresh (UpDevice *device)
+up_device_hid_refresh (UpDevice *device, UpRefreshReason reason)
 {
 	gboolean set = FALSE;
 	gboolean ret = FALSE;
@@ -472,9 +458,6 @@ up_device_hid_init (UpDeviceHid *hid)
 {
 	hid->priv = up_device_hid_get_instance_private (hid);
 	hid->priv->fd = -1;
-	hid->priv->poll_timer_id = g_timeout_add_seconds (UP_DEVICE_HID_REFRESH_TIMEOUT,
-							  (GSourceFunc) up_device_hid_poll, hid);
-	g_source_set_name_by_id (hid->priv->poll_timer_id, "[upower] up_device_hid_poll (linux)");
 }
 
 /**
@@ -493,8 +476,6 @@ up_device_hid_finalize (GObject *object)
 
 	if (hid->priv->fd > 0)
 		close (hid->priv->fd);
-	if (hid->priv->poll_timer_id > 0)
-		g_source_remove (hid->priv->poll_timer_id);
 
 	G_OBJECT_CLASS (up_device_hid_parent_class)->finalize (object);
 }
@@ -513,13 +494,3 @@ up_device_hid_class_init (UpDeviceHidClass *klass)
 	device_class->get_on_battery = up_device_hid_get_on_battery;
 	device_class->refresh = up_device_hid_refresh;
 }
-
-/**
- * up_device_hid_new:
- **/
-UpDeviceHid *
-up_device_hid_new (void)
-{
-	return g_object_new (UP_TYPE_DEVICE_HID, NULL);
-}
-
